@@ -1,5 +1,8 @@
 #/usr/bin/perl
 
+use warnings;
+use strict;
+
 use Net::DBus;
 use Carp qw(cluck carp confess);
 #$SIG{__WARN__} = sub { cluck $_[0] };
@@ -22,11 +25,14 @@ my $dict = $object->GetDict();
 
 print "{", join(", ", map { "'$_': '" . $dict->{$_} . "'"} keys %{$dict}), "}\n";
 
-if (0) {
+if (1) {
     $object->name("John Doe");
-    $object->age(21);
-#$object->email('john.doe@example.com');
+    $object->salary(100000);
+    # Email is readonly, so we expect this to fail
+    eval {
+	$object->email('john.doe@example.com');
+    };
     
-    print $object->name, " ", " ", $object->email, "\n";
+    print $object->name, " ", $object->email, "\n";
 
 }
