@@ -1,22 +1,20 @@
 # -*- perl -*-
 #
-# Copyright (C) 2004-2005 Daniel P. Berrange
+# Copyright (C) 2004-2011 Daniel P. Berrange
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# This program is free software; You can redistribute it and/or modify
+# it under the same terms as Perl itself. Either:
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# a) the GNU General Public License as published by the Free
+#   Software Foundation; either version 2, or (at your option) any
+#   later version,
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# or
 #
-# $Id: Server.pm,v 1.5 2006/01/27 15:34:24 dan Exp $
+# b) the "Artistic License"
+#
+# The file "COPYING" distributed along with this file provides full
+# details of the terms and conditions of the two licenses.
 
 =pod
 
@@ -64,7 +62,7 @@ may be of use.
 
 =head1 METHODS
 
-=over 
+=over
 
 =cut
 
@@ -73,7 +71,6 @@ package Net::DBus::Binding::Server;
 use 5.006;
 use strict;
 use warnings;
-use Carp;
 
 use Net::DBus;
 use Net::DBus::Binding::Connection;
@@ -91,7 +88,7 @@ sub new {
     my %params = @_;
     my $self = {};
 
-    $self->{address} = exists $params{address} ? $params{address} : confess "address parameter is required";
+    $self->{address} = exists $params{address} ? $params{address} : die "address parameter is required";
     $self->{server} = Net::DBus::Binding::Server::_open($self->{address});
 
     bless $self, $class;
@@ -121,7 +118,7 @@ otherwise a positive value is returned.
 
 sub is_connected {
     my $self = shift;
-    
+
     return $self->{server}->dbus_server_get_is_connected();
 }
 
@@ -136,14 +133,14 @@ explicitly disconnect.
 
 sub disconnect {
     my $self = shift;
-    
+
     return $self->{server}->dbus_server_disconnect();
 }
 
 
 =item $server->set_watch_callbacks(\&add_watch, \&remove_watch, \&toggle_watch);
 
-Register a set of callbacks for adding, removing & updating 
+Register a set of callbacks for adding, removing & updating
 watches in the application's event loop. Each parameter
 should be a code reference, which on each invocation, will be
 supplied with two parameters, the server object and the
@@ -169,7 +166,7 @@ sub set_watch_callbacks {
 
 =item $server->set_timeout_callbacks(\&add_timeout, \&remove_timeout, \&toggle_timeout);
 
-Register a set of callbacks for adding, removing & updating 
+Register a set of callbacks for adding, removing & updating
 timeouts in the application's event loop. Each parameter
 should be a code reference, which on each invocation, will be
 supplied with two parameters, the server object and the
@@ -220,16 +217,16 @@ sub set_connection_callback {
 
 =back
 
+=head1 AUTHOR
+
+Daniel P. Berrange
+
+=head1 COPYRIGHT
+
+Copyright (C) 2004-2011 Daniel P. Berrange
+
 =head1 SEE ALSO
 
 L<Net::DBus::Binding::Connection>, L<Net::DBus::Binding::Bus>, L<Net::DBus::Binding::Message::Signal>, L<Net::DBus::Binding::Message::MethodCall>, L<Net::DBus::Binding::Message::MethodReturn>, L<Net::DBus::Binding::Message::Error>
 
-=head1 AUTHOR
-
-Daniel Berrange E<lt>dan@berrange.comE<gt>
-
-=head1 COPYRIGHT
-
-Copyright 2004 by Daniel Berrange
-
 =cut
